#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2014 Adrian Perez <aperez@igalia.com>
#
# Distributed under terms of the MIT license.

def FlagsForFile(path, **kwarg):
    return { 'flags': ['-Wall'], 'do_cache': True }

